"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** 缓存管理 */
var Cache = /** @class */ (function () {
    function Cache() {
        this.map = new Map();
    }
    /**
     * 设置缓存
     * @param key - 键
     * @param value - 值
     * @param expire - 有效期(毫秒)
     */
    // tslint:disable-next-line: no-reserved-keywords
    Cache.prototype.set = function (key, value, expire) {
        this.map.set(key, [value, expire > 0 ? Date.now() + expire : 0]);
    };
    /**
     * 获取缓存，不存在返回undefined
     * @param key - 键
     */
    // tslint:disable-next-line: no-reserved-keywords
    Cache.prototype.get = function (key) {
        if (this.map.has(key)) {
            var _a = this.map.get(key), value = _a[0], expireTime = _a[1];
            if (expireTime >= Date.now()) {
                return value;
            }
            else {
                this.map.delete(key);
            }
        }
        return undefined;
    };
    /**
     * 删除缓存，返回是否删除成功
     * @param key - 键
     */
    // tslint:disable-next-line: no-reserved-keywords
    Cache.prototype.delete = function (key) {
        return this.map.delete(key);
    };
    /**
     * 缓存是否存在
     * @param key - 键
     */
    Cache.prototype.has = function (key) {
        if (this.map.has(key)) {
            if (this.map.get(key)[1] > Date.now()) {
                return true;
            }
            this.map.delete(key);
        }
        return false;
    };
    return Cache;
}());
exports.Cache = Cache;
//# sourceMappingURL=cache.js.map